==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebAvatarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAvatarDescription } from "./WebAvatarDescription";
/**
 * @hidden
 */
export let WebAvatarDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebAvatarDescriptionMetadata extends Base {
        static b(a) {
            if (WebAvatarDescriptionMetadata.a == null) {
                WebAvatarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebAvatarDescriptionMetadata.c(WebAvatarDescriptionMetadata.a);
            }
            if (a.k(WebAvatarDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebAvatarDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Avatar");
            a.item("__tagNameWC", "String:igc-avatar");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Src", "String");
            a.item("Alt", "String");
            a.item("Initials", "String");
            a.item("Shape", "ExportedType:string:AvatarShape");
            a.item("Shape@stringUnion", "WebComponents;React");
            a.item("Shape@names", "Circle;Rounded;Square");
            a.item("Size", "ExportedType:string:SizableComponentSize");
            a.item("Size@names", "Large;Small;Medium");
        }
        static d(a) {
            WebAvatarDescriptionMetadata.b(a);
            a.ad("WebAvatar", () => new WebAvatarDescription());
            a.ac("WebAvatar", WebAvatarDescriptionMetadata.a);
        }
    }
    WebAvatarDescriptionMetadata.$t = markType(WebAvatarDescriptionMetadata, 'WebAvatarDescriptionMetadata');
    WebAvatarDescriptionMetadata.a = null;
    return WebAvatarDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebAvatarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebAvatarDescription } from "./WebAvatarDescription";
/**
 * @hidden
 */
export let WebAvatarDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebAvatarDescriptionMetadata extends Base {
        static b(a) {
            if (WebAvatarDescriptionMetadata.a == null) {
                WebAvatarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebAvatarDescriptionMetadata.c(WebAvatarDescriptionMetadata.a);
            }
            if (a.k(WebAvatarDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebAvatarDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Avatar");
            a.item("__tagNameWC", "String:igc-avatar");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Src", "String");
            a.item("Alt", "String");
            a.item("Initials", "String");
            a.item("Shape", "ExportedType:string:AvatarShape");
            a.item("Shape@stringUnion", "WebComponents;React");
            a.item("Shape@names", "Square;Circle;Rounded");
        }
        static d(a) {
            WebAvatarDescriptionMetadata.b(a);
            a.ae("WebAvatar", () => new WebAvatarDescription());
            a.ad("WebAvatar", WebAvatarDescriptionMetadata.a);
        }
    }
    WebAvatarDescriptionMetadata.$t = markType(WebAvatarDescriptionMetadata, 'WebAvatarDescriptionMetadata');
    WebAvatarDescriptionMetadata.a = null;
    return WebAvatarDescriptionMetadata;
})();
